@@ -1,7 +1,8 @@
 #!perl
 
-use feature 'say';
 use common::sense;
+use Test2::V0;
+use Coro;
 use Data::Dump::Streamer;
 use MIME::Base64 qw(encode_base64 decode_base64);
 use Ion;
@@ -23,8 +24,17 @@ $client
   >> sub{ Dump(shift)->Purity(1)->Declare(1)->Indent(0)->Out }
   >> sub{ encode_base64($_[0], '') };
 
-foreach my $i (1 .. $count) {
-  $client->([\&work, $i]);
-  my $result = <$client>;
-  say $i, ' * 2 = ', $result;
-}
+my @pending = map{
+  async{
+      my ($client, $i) = @_;
+      $client->([\&work, $i]);
+      my $result = <$client>;
+      is $result, $i * 2, "recv: $i * 2 = $result";
+    }
+    $client,
+    $_;
+} 1 .. $count;
+
+$_->join foreach @pending;
+
+done_testing;
