@@ -1,18 +1,22 @@
 package Ion::Test;
 # ABSTRACT: Utilities used by Ion unit tests
-$Ion::Test::VERSION = '0.07_02'; # TRIAL
-
-$Ion::Test::VERSION = '0.0702';use common::sense;
+$Ion::Test::VERSION = '0.08';
+use common::sense;
 
 BEGIN{
   require Test2::V0;
 
   if ($^O =~ /mswin32/i) {
-    my $ok; local $SIG{CHLD} = sub { $ok = 1 }; kill 'CHLD', 0;
-    Test2::V0::skip_all('broken perl detected') unless $ok;
+    my $ok;
+    local $SIG{CHLD} = sub{ $ok = 1 };
+    kill 'CHLD', 0;
+
+    Test2::V0::skip_all('broken perl detected: $SIG{CHLD}')
+      unless $ok;
   }
 
-  Test2::V0::skip_all('broken perl detected') unless exists $SIG{USR1};
+  Test2::V0::skip_all('broken perl detected: $SIG{USR1}')
+    unless exists $SIG{USR1};
 
   require AnyEvent::Impl::Perl;
 }
@@ -31,7 +35,7 @@ Ion::Test - Utilities used by Ion unit tests
 
 =head1 VERSION
 
-version 0.07_02
+version 0.08
 
 =head1 AUTHOR
 
